/**
 * DirectX technique for the SIRDS Viewer.
 *
 * Render depth information to shades of grey using this vertex shader (VS1.0).
 *
 * (C) 2005, Giliam de Carpentier. Released under the GNU GPL license.
 */
 
//--------------------------------------------------------------------------------------
// Global variables
//--------------------------------------------------------------------------------------
float    g_fRampNearPlane;
float	 g_fRampNearScale;
float4x4 g_mWorldViewProjection;    // World * View * Projection matrix


//--------------------------------------------------------------------------------------
// Vertex shader output structure
//--------------------------------------------------------------------------------------
struct VS_OUTPUT
{
    float4 Position   : POSITION;   // vertex position 
    float4 Diffuse    : COLOR0;     // vertex diffuse color (note that COLOR0 is clamped from 0..1)
};


//--------------------------------------------------------------------------------------
// This shader computes standard transform and lighting
//--------------------------------------------------------------------------------------
VS_OUTPUT RenderSceneVS( float4 vPos : POSITION, 
                         float3 vNormal : NORMAL,
                         float2 vTexCoord0 : TEXCOORD0,
                         uniform int nNumLights,
                         uniform bool bTexture,
                         uniform bool bAnimate )
{
    VS_OUTPUT Output;
    float3 vNormalWorldSpace;
    
    // Transform the position from object space to homogeneous projection space
    Output.Position = mul(vPos, g_mWorldViewProjection);
    
	Output.Diffuse = g_fRampNearScale / (Output.Position.z - g_fRampNearPlane);
    
    return Output;    
}


//--------------------------------------------------------------------------------------
// Pixel shader output structure
//--------------------------------------------------------------------------------------
struct PS_OUTPUT
{
    float4 RGBColor : COLOR0;  // Pixel color    
};


//--------------------------------------------------------------------------------------
// This shader outputs the pixel's color by modulating the texture's
//       color with diffuse material color
//--------------------------------------------------------------------------------------
PS_OUTPUT RenderScenePS( VS_OUTPUT In,
                         uniform bool bTexture ) 
{ 
    PS_OUTPUT Output;

    // Lookup mesh texture and modulate it with diffuse
//    if( bTexture )
//        Output.RGBColor = tex2D(MeshTextureSampler, In.TextureUV) * In.Diffuse;
//    else
        Output.RGBColor = In.Diffuse;
        
    return Output;
}


//--------------------------------------------------------------------------------------
// Renders scene to render target
//--------------------------------------------------------------------------------------
technique DepthRamp
{
    pass P0
    {          
        VertexShader = compile vs_1_0 RenderSceneVS( 1, true, true );
        PixelShader  = NULL;
    }
}